@@ -79,7 +79,7 @@ impl RendezvousError {
 type MessageQueue = VecDeque<EncryptedMessage>;
 
 #[derive(Clone, Debug, derive_more::Display)]
-#[display(fmt = "{:?}", _0)]
+#[display("{:?}", _0)]
 struct NameplateList(Vec<Nameplate>);
 
 #[cfg(not(target_family = "wasm"))]
@@ -100,9 +100,9 @@ impl WsConnection {
         message: &OutboundMessage,
         queue: Option<&mut MessageQueue>,
     ) -> Result<(), RendezvousError> {
-        log::debug!("Sending {}", message);
+        tracing::debug!("Sending {}", message);
         self.connection
-            .send(ws2::Message::Text(serde_json::to_string(message).unwrap()))
+            .send(ws2::Message::text(serde_json::to_string(message).unwrap()))
             .await?;
         self.receive_ack(queue).await?;
         Ok(())
@@ -114,7 +114,7 @@ impl WsConnection {
         message: &OutboundMessage,
         queue: Option<&mut MessageQueue>,
     ) -> Result<(), RendezvousError> {
-        log::debug!("Sending {:?}", message);
+        tracing::debug!("Sending {:?}", message);
         self.connection
             .send(ws_stream_wasm::WsMessage::Text(
                 serde_json::to_string(message).unwrap(),
@@ -214,10 +214,10 @@ impl WsConnection {
         match message {
             ws2::Message::Text(message_plain) => {
                 let message = serde_json::from_str(&message_plain)?;
-                log::debug!("Received {}", message);
+                tracing::debug!("Received {}", message);
                 match message {
                     InboundMessage::Unknown => {
-                        log::warn!("Got unknown message, ignoring: '{}'", message_plain);
+                        tracing::warn!("Got unknown message, ignoring: '{}'", message_plain);
                         Ok(None)
                     },
                     InboundMessage::Error { error, orig: _ } => Err(RendezvousError::server(error)),
@@ -231,11 +231,11 @@ impl WsConnection {
             ws2::Message::Ping(_) => Ok(None),
             ws2::Message::Pong(_) => Ok(None),
             ws2::Message::Close(_) => {
-                log::debug!("Received connection close");
+                tracing::debug!("Received connection close");
                 Err(ws2::Error::ConnectionClosed.into())
             },
             ws2::Message::Frame(_) => {
-                log::warn!("Received a WebSocket 'Frame' message and don't know what to do with it, please open a bug report");
+                tracing::warn!("Received a WebSocket 'Frame' message and don't know what to do with it, please open a bug report");
                 Ok(None)
             },
         }
@@ -251,10 +251,10 @@ impl WsConnection {
         match message {
             ws_stream_wasm::WsMessage::Text(message_plain) => {
                 let message = serde_json::from_str(&message_plain)?;
-                log::debug!("Received {:?}", message);
+                tracing::debug!("Received {:?}", message);
                 match message {
                     InboundMessage::Unknown => {
-                        log::warn!("Got unknown message, ignoring: '{}'", message_plain);
+                        tracing::warn!("Got unknown message, ignoring: '{}'", message_plain);
                         Ok(None)
                     },
                     InboundMessage::Error { error, orig: _ } => Err(RendezvousError::server(error)),
@@ -289,7 +289,7 @@ enum RendezvousReply {
 
 #[derive(Clone, Debug, derive_more::Display)]
 #[display(
-    fmt = "MailboxMachine {{ mailbox: {}, processed: [{}] }}",
+    "MailboxMachine {{ mailbox: {}, processed: [{}] }}",
     mailbox,
     "processed.iter().map(|p| format!(\"{}\", p)).collect::<Vec<String>>().join(\", \")"
 )]
@@ -409,7 +409,7 @@ impl RendezvousServer {
             .send_message(&OutboundMessage::bind(appid.clone(), side.clone()), None)
             .await?;
 
-        log::info!("Connected to rendezvous server.");
+        tracing::info!("Connected to rendezvous server.");
 
         Ok((
             Self {
@@ -572,8 +572,7 @@ impl RendezvousServer {
             .and_then(|state| state.nameplate.clone())
             .expect("Can only release an allocated nameplate, and only once");
 
-        use std::ops::Deref;
-        self.send_message(&OutboundMessage::release(nameplate.deref().deref()))
+        self.send_message(&OutboundMessage::release(nameplate.as_ref()))
             .await?;
         match self.receive_reply().await? {
             RendezvousReply::Released => (),
